local m, o, s
local uci = require "luci.model.uci".cursor()

local uciget = uci:get("firewall", "TR069")
if not uciget then
	uci:set("firewall", "TR069", "rule")
	uci:set("firewall", "TR069", "target", "ACCEPT")
	uci:set("firewall", "TR069", "src", "wan")
	uci:set("firewall", "TR069", "proto", "tcp")
	uci:set("firewall", "TR069", "dest_port", "7547")
	uci:set("firewall", "TR069", "name", "Allow_TR069_server_request")
	uci:set("firewall", "TR069", "enabled", "0")
	uci:commit("firewall")
end

m = Map("easycwmp")

s = m:section(TypedSection, "acs", translate("TR-069 Client Configuration"))
s.anonymous = true

o = s:option(Flag, "enabled", translate("Enable"), translate("Enables TR-069 client"))
o.rmempty = false

o = s:option(Flag, "periodic_enable", translate("Periodic enable"), translate("Enables TR-069 client periodic data transmission to TR-069 server"))
o.rmempty = false

o = s:option(Flag, "server_request", translate("Accept server request"), translate(""))
o.rmempty = false

function o.write(self, section, value)
	m.uci:set("firewall", "TR069", "enabled", value)
end

function o.cfgvalue(self, section)
	local value = m.uci:get("firewall", "TR069", "enabled")
	return value
end

o = s:option(Value, "periodic_interval", translate("Sending interval"), translate("Periodic data transmission interval (allowed: 60s-9999999s)"))
o.datatype = "range(60,9999999)"
o.default = "3600"
o.placeholder = "100"
o.rmempty = false

o = s:option(Value, "username", translate("Username"), translate("User name for authentication on TR-069 server. Allowed characters (a-zA-Z0-9!@#$%&*+-/=?^_`{|}~. )"))
o.datatype = "fieldvalidation('^[a-zA-Z0-9!@#$%%&*+/=?^_`{|}~. -]+$',0)"
o.maxlength = "64"
o.placeholder = "Username"
o.rmempty = false


o = s:option(Value, "password", translate("Password"), translate("Password for authentication on TR-069 server"))
o.password = true
o.datatype = "credentials_validate"
o.maxlength = "64"
o.placeholder = "Password"
o.rmempty = false


o = s:option(Value, "url", translate("URL"), translate("TR-069 server's URL to send data to"))
o.default = "http://192.168.1.110:8080/openacs/acs"
o.datatype = "string"
o.maxlength = "128"
o.rmempty = false

return m
